@@ -818,7 +818,7 @@ class MachineModelSettingsPopUp(PopUpMixin, ConfigReader):
         if 'shap_multiprocess' in self.meta.keys():
             self.shap_multiprocess_dropdown.setChoices(self.meta['shap_multiprocess'])
         if "partial_dependency" in self.meta.keys():
-            if self.meta["partial_dependency"] in Options.RUN_OPTIONS_FLAGS.value:
+            if self.meta["partial_dependency"] in Options.PERFORM_FLAGS.value:
                 self.partial_dependency_var.set(value=True)
         else:
             self.shap_save_it_dropdown.setChoices("None")
