@@ -274,19 +274,20 @@ def get_cmaps() -> List[str]:
 
 
 def get_categorical_palettes():
-    return ['Pastel1',
-            'Pastel2',
-            'Paired',
-            'Accent',
-            'Dark2',
-            'Set1',
-            'Set2',
-            'Set3',
-            'tab10',
-            'tab20',
-            'tab20b',
-            'tab20c']
-
+    return [
+        "Pastel1",
+        "Pastel2",
+        "Paired",
+        "Accent",
+        "Dark2",
+        "Set1",
+        "Set2",
+        "Set3",
+        "tab10",
+        "tab20",
+        "tab20b",
+        "tab20c",
+    ]
 
 
 def get_color_dict() -> Dict[str, Tuple[int]]:
